#include "knap_homepanel.h"
#include <qlayout.h>  
#include <qfile.h>
#include <qwidget.h>

#include <iostream>
using namespace std;

//#include "welcome-html.h"

KNAP_HomePanel::KNAP_HomePanel(QWidget *parent,const char *name)
   : QWidget(parent,name)
{

   QGridLayout *lo=new QGridLayout(this,2,1,1,0);
   
   part = new KHTMLPart(this,name);

   lo->addWidget(part->view(),0,0);

}
KNAP_HomePanel::~KNAP_HomePanel()
{

}

bool KNAP_HomePanel::loadDefault()
{
   // TODO
    
#ifdef WELCOME_PAGE
   cerr << "KNAP_HomePanel::loadDefault(): " << WELCOME_PAGE << endl;
   if(QFile::exists(WELCOME_PAGE))
   {
     KURL url = "file:" WELCOME_PAGE; //"http://lost.bard/knapster-welcome.html";
     part->openURL(url);
   }
#endif   
  // part->show();

   return true;
}

